@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter;
 
 # ABSTRACT: Tell Log::Any where to send its logs
-our $VERSION = '1.033'; # TRIAL
+our $VERSION = '1.035'; # TRIAL
 
 use Log::Any;
 
@@ -38,7 +38,7 @@ Log::Any::Adapter - Tell Log::Any where to send its logs
 
 =head1 VERSION
 
-version 1.033
+version 1.035
 
 =head1 SYNOPSIS
 
@@ -84,7 +84,7 @@ Log::Any::Adapter - Tell Log::Any where to send its logs
 
 =head1 VERSION
 
-version 1.033
+version 1.035
 
 =head1 ADAPTERS
 
@@ -185,7 +185,10 @@ adapter setting will be removed. e.g.
 
 =back
 
-C<set> returns an entry object, which can be passed to C<remove>.
+C<set> returns an entry object, which can be passed to C<remove>.  If you
+call C<set> repeatedly without calling C<remove> you will leak memory.  For
+most programs that set an adapter once until the end of the program, this
+shouldn't matter.
 
 =item use Log::Any::Adapter (...)
 
@@ -198,11 +201,25 @@ Remove an I<entry> previously returned by C<set>.
 
 =back
 
-=head1 MULTIPLE ADAPTER SETTINGS
+=head1 USING MORE THAN ONE ADAPTER
 
-C<Log::Any> maintains a stack of entries created via C<set>.
+C<Log::Any> maintains a stack of entries created via C<set>.  If you call
+C<set> repeatedly, you will leak memory unless you do one of the
+following:
 
-When you get a logger for a particular category, C<Log::Any> will work its way
+=over 4
+
+=item *
+
+call C<remove> on the adapter returned from C<set> when you are done with it
+
+=item *
+
+use the C<lexically> feature to set a guard variable that will clean it up when it goes out of scope
+
+=back
+
+When getting a logger for a particular category, C<Log::Any> will work its way
 down the stack and use the first matching entry.
 
 Whenever the stack changes, any C<Log::Any> loggers that have previously been
